Any contribution to the code base or plan documents, big or small, is very welcome.

# Contribution Process

All contributions as welcome in any of the following forms:
* issues: feature requests, use cases, and suggestions on how to improve visualizations, together with bug reports.
* code: contributing any code via a pull request, to solve any existing issue (please have/create a corresponding issue before making a pull request)
* reviews: comments on any issue and/or pull request, feedback of all forms is welcome.

# Stages of Development

We will be implementing features in the following stages, more details about plans will be available on the Wiki:
1. Make basic plotting tools
2. Make available support for Cirq, Qiskit, PyQuil
3. Create tests, documentation, examples
4. Create tools for visualizing solutions in contrast to classical solvers
